<?php

namespace Teknisa\ACL\Controllers;

use Teknisa\ACL\Services\PerfAcessParc as PerfAcessParcService;
use Teknisa\ACL\Util\AclUtilities;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\ACL\Util\InstanceProvider;
use Teknisa\Libs\Util\Environment as Environment;

class PerfAcessParc extends Crud{

    const IS_NEW = "__is_new";

    protected $dataSourceName = "perfAcessParcOperador";
    protected $dataSourceNameSave = "perfAcessParc";
    private   $environment;

    /** @var PerfAcessParcService */
    protected $perfAcessParcService;

    public function __construct(Manager $manager, PerfAcessParcService $perfAcessParcService, Environment $environment) {
        $this->perfAcessParcService = $perfAcessParcService;
        $this->environment = $environment;
        parent::__construct($manager);
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $request->getFilterCriteria()->addCondition(PerfAcessParcService::NRORG, $this->perfAcessParcService->getNrOrgFilter());
        parent::find($request, $response);
    }
    
    public function deleteOperator(DTO\Request $request, DTO\Response $response) {
            $rows       = $request->getDataSet()->getRows()[0];
        if($this->environment->getIdUtlPerfilFilial() != 'N' && $rows['SHOW_FULL_OPERATOR']){
            $data = InstanceProvider::getService()->getPerfAcessParc()->deleteOperatorPerfAccessFili($rows);
        } else {
            parent::delete($request, $response);
        }
    }

    public function save(DTO\Request\DataSet $request, DTO\Response $response) {
        $rows       = $request->getDataSet()->getRows()[0];
        if($this->environment->getIdUtlPerfilFilial() != 'N' && $rows['SHOW_FULL_OPERATOR']){
            self::saveOperadorPerfAccessFili($request, $response);    
        } else {
            self::saveOperador($request, $response);
        }
    }
    
    public function saveOperador($request, $response){
        foreach($request->getDataSet()->getRows() as $row) {
            if(!$row['NRPARCNEGOCIO']) {
                $businessPartnership = InstanceProvider::getService()->getOperator()->setBusinessPartnership(
                                $row['NMOPERADOR'], $row['NRINSCRICAOPARC'], $row['IDATIVO'], $row['CDOPERINCLUSAO'],
                                $row['CDTIPOINSCRICAO'], $row['CDOPERADOR']);
                $row['NRPARCNEGOCIO'] = $businessPartnership['NRPARCNEGOCIO'];
            }
            if ($row[self::IS_NEW]) {
                $row[PerfAcessParcService::NRPERFACESSPARC] = $this->perfAcessParcService->getMaxNrPerfilAcesso();
            }            
            $this->perfAcessParcService->setDefaultValues($row);
        }
        $originalDataSourceName = $this->dataSourceName;
        $this->dataSourceName = $this->dataSourceNameSave;
        parent::save($request, $response);
        $this->dataSourceName = $originalDataSourceName;
    }
    
    public function saveOperadorPerfAccessFili(DTO\Request\DataSet $request, DTO\Response $response) {
        $row = $request->getDataSet()->getRows();
        $data = InstanceProvider::getService()->getPerfAcessParc()->saveOperadorPerfAccessFili($row);
    }

    public function findPerfAcessParcOperador(DTO\Request\Filter $request, DTO\Response $response)
    {
        $request->getFilterCriteria()->addCondition("NRORG", $this->environment->getCurrentOrganizationId());
        $conditions       = $request->getFilterCriteria()->getConditions();
        $showFullOperator = AclUtilities::getValueInFilterDataSourceByName($conditions, 'SHOW_FULL_OPERATOR', true);
        $orderBy          = $request->getFilterCriteria()->getOrderBy();
        $utlPerfilfilial  = $this->environment->getIdUtlPerfilFilial();

        if($utlPerfilfilial != 'N' && $showFullOperator) {
            $data = InstanceProvider::getService()->getPerfAcessParc()->findPerfAcessFilial($conditions, $orderBy);
        } else {
            $data = InstanceProvider::getService()->getPerfAcessParc()->findPerfAcessParcOperador($conditions, $orderBy);
        }
        $response->addDataSet(new DataSet('findPerfAcessParcOperador', $data));
    }

}